@@ -64,7 +64,7 @@ inline void key_press_event(int key2,int type)
 {
 	int  psxkey1 = -1, psxkey2 = -1;
 	int key=keymap[key2];
-	
+
 	if (key < 0){
 		return;
 	}
@@ -96,8 +96,10 @@ inline void key_press_event(int key2,int type)
 			{
 				emu_save_state(state_slot);
 				char buf[MAXPATHLEN];
-				sprintf (buf,"/opt/maemo/usr/games/screenshots%s.%3.3d",file_name,state_slot);
-				writepng(buf, image->mem, pl_buf_w,pl_buf_h);
+				if (image && image->mem){
+                    sprintf (buf,"/opt/maemo/usr/games/screenshots%s.%3.3d",file_name,state_slot);
+                    writepng(buf, image->mem, pl_buf_w,pl_buf_h);
+				}
 			}
 			return;
 		case 20:
@@ -150,7 +152,7 @@ void maemo_init(int *argc, char ***argv)
 		}
 		fclose(pFile);
 	}
-	
+
 	pFile = fopen("/opt/psx4m/config", "r");
 	if (NULL != pFile) {
 		fscanf(pFile, "%d %d",&sens,&y_def);
@@ -242,14 +244,14 @@ void *hildon_flip(void)
 
 		y+=y_def;
 		if( y > sens )in_keystate |= 1 << DKEY_UP;
-		else if( y < -sens ) in_keystate |= 1 << DKEY_DOWN; 
+		else if( y < -sens ) in_keystate |= 1 << DKEY_DOWN;
 		else {in_keystate &= ~(1 << DKEY_DOWN);in_keystate &= ~(1 << DKEY_UP);}
 
 	}
 
-	if (g_maemo_opts&8) 
-		maemo_x11_update_keys(); 
-	else 
+	if (g_maemo_opts&8)
+		maemo_x11_update_keys();
+	else
 		/* process GTK+ events */
 		while (gtk_events_pending())
 			gtk_main_iteration();
