@@ -37,7 +37,6 @@ static void InitKeyboard(void) {
 	wmprotocols = XInternAtom(disp, "WM_PROTOCOLS", 0);
 	wmdelwindow = XInternAtom(disp, "WM_DELETE_WINDOW", 0);
 	XkbSetDetectableAutoRepeat(disp, 1, NULL);
-
 }
 
 static void DestroyKeyboard(void) {
@@ -49,11 +48,11 @@ static void DestroyKeyboard(void) {
 
 int maemo_x11_update_keys() {
 
-	uint8_t					i;
+	//uint8_t					i;
 	XEvent					evt;
 	XClientMessageEvent		*xce;
-	uint16_t				Key;
-	int psxkey, leave = 0;
+	//uint16_t				Key;
+	int /*psxkey,*/ leave = 0;
 	Display *disp = (Display *)gpuDisp;
 	
 	if (!disp)
@@ -69,7 +68,7 @@ int maemo_x11_update_keys() {
 		switch (evt.type) {
 			case KeyPress:
 			case KeyRelease:
-				key_press_event(evt.xkey.keycode,evt.type==KeyPress?1:(evt.type==KeyRelease?2:0) );
+				key_press_event(evt.xkey.keycode, evt.type==KeyPress ? 1 : (evt.type==KeyRelease ? 2 : 0) );
 
 			case ClientMessage:
 				xce = (XClientMessageEvent *)&evt;
