@@ -21,6 +21,8 @@
 
 // sound plugin
 extern int iUseTimer;
+extern int iUseReverb;
+extern int iUseInterpolation;
 
 int g_opts = 0;
 int g_maemo_opts;
@@ -84,6 +86,15 @@ void PrintHelp()
 	printf("  -oldgpu        : Use the peops plugin (gpu_peops.so)\n");
 	printf("  -unai          : Use the unai plugin (gpu_unai.so)\n");
 
+	printf("\nSound Options:\n");
+	printf("  -spu_reverb VALUE        : Enable/disable reverb [0/1]\n");
+    printf("                             (Default disabled)\n");
+	printf("  -spu_interpolation VALUE : Set interpolation mode\n");
+	printf("                             0=None (Default)\n");
+    printf("                             1=Simple\n");
+	printf("                             2=Gaussian\n");
+	printf("                             3=Cubic\n");
+
 /*
 	printf("\nNeon Options (default GPU):\n");
 	printf("  -neon_interlace VALUE : Set interlce mode\n");
@@ -135,6 +146,8 @@ int maemo_main(int argc, char **argv)
 	Config.PsxAuto = 1;
 	pl_rearmed_cbs.frameskip = -1;
 	strcpy(Config.Bios, "HLE");
+    iUseReverb = 0;
+    iUseInterpolation = 0;
 
 	// read command line options
 	for (i = 1; i < argc; i++) {
@@ -164,35 +177,37 @@ int maemo_main(int argc, char **argv)
 		}
 		else if (!strcmp(argv[i],"-region")) {
 			int psx_reg = atol(argv[++i]);
-			if (psx_reg == 0 || psx_reg == 1){				
+			if (psx_reg == 0 || psx_reg == 1){
 				Config.PsxAuto = 0;
 				Config.PsxType = psx_reg;
 			}
 		}
-		else if (!strcmp(argv[i], "-fullscreen"))		g_maemo_opts |= 2;
+		else if (!strcmp(argv[i], "-fullscreen"))	        { g_maemo_opts |= 2; pl_rearmed_cbs.gpu_peopsgl.bKeepRatio = 0; }
 		else if (!strcmp(argv[i], "-accel"))				g_maemo_opts |= 4;
-		else if (!strcmp(argv[i], "-sputhreaded"))		iUseTimer=1;
-		else if (!strcmp(argv[i], "-nosound"))		strcpy(Config.Spu, "spunull.so");
-		else if (!strcmp(argv[i], "-bdir"))			sprintf(Config.BiosDir, "%s", argv[++i]);
-		else if (!strcmp(argv[i], "-pdir"))			sprintf(Config.PluginsDir, "%s", argv[++i]);
-		else if (!strcmp(argv[i], "-bios"))			sprintf(Config.Bios, "%s", argv[++i]);
-		else if (!strcmp(argv[i], "-gles"))			{strcpy(Config.Gpu, "gpuGLES.so");g_maemo_opts |=8 ;}
-		else if (!strcmp(argv[i], "-4all"))			strcpy(Config.Gpu, "gpuPCSX4ALL.so");
-		else if (!strcmp(argv[i], "-oldgpu"))		strcpy(Config.Gpu, "gpu_peops.so");
-		else if (!strcmp(argv[i], "-unai"))		strcpy(Config.Gpu, "gpu_unai.so");
-		else if (!strcmp(argv[i], "-cdda"))		Config.Cdda = 1;
-		else if (!strcmp(argv[i], "-xa"))		Config.Xa = 1;
-		else if (!strcmp(argv[i], "-rcnt"))		Config.RCntFix = 1 ;
-		else if (!strcmp(argv[i], "-sio"))		Config.Sio = 1;
-		else if (!strcmp(argv[i], "-spuirq"))	Config.SpuIrq = 1;
-		else if (!strcmp(argv[i], "-vsync"))	Config.VSyncWA = 1;
-		else if (!strcmp(argv[i], "-fps")) 		g_opts |=OPT_SHOWFPS;
-		else if (!strcmp(argv[i], "-cpu")) 		g_opts |=OPT_SHOWCPU;
-		else if (!strcmp(argv[i], "-spu")) 		g_opts |=OPT_SHOWSPU;
-		else if (!strcmp(argv[i], "-nofl")) 		g_opts |=OPT_NO_FRAMELIM;
-		else if (!strcmp(argv[i], "-mcd1")) 	sprintf(Config.Mcd1, "%s", argv[++i]);
-		else if (!strcmp(argv[i], "-mcd2")) 	sprintf(Config.Mcd2, "%s", argv[++i]);
+		else if (!strcmp(argv[i], "-sputhreaded"))		    iUseTimer=1;
+		else if (!strcmp(argv[i], "-nosound"))		        strcpy(Config.Spu, "spunull.so");
+		else if (!strcmp(argv[i], "-bdir"))			        sprintf(Config.BiosDir, "%s", argv[++i]);
+		else if (!strcmp(argv[i], "-pdir"))			        sprintf(Config.PluginsDir, "%s", argv[++i]);
+		else if (!strcmp(argv[i], "-bios"))			        sprintf(Config.Bios, "%s", argv[++i]);
+		else if (!strcmp(argv[i], "-gles"))			        {strcpy(Config.Gpu, "gpuGLES.so");g_maemo_opts |=8 ;}
+		else if (!strcmp(argv[i], "-4all"))			        strcpy(Config.Gpu, "gpuPCSX4ALL.so");
+		else if (!strcmp(argv[i], "-oldgpu"))		        strcpy(Config.Gpu, "gpu_peops.so");
+		else if (!strcmp(argv[i], "-unai"))		            strcpy(Config.Gpu, "gpu_unai.so");
+		else if (!strcmp(argv[i], "-cdda"))		            Config.Cdda = 1;
+		else if (!strcmp(argv[i], "-xa"))		            Config.Xa = 1;
+		else if (!strcmp(argv[i], "-rcnt"))		            Config.RCntFix = 1 ;
+		else if (!strcmp(argv[i], "-sio"))		            Config.Sio = 1;
+		else if (!strcmp(argv[i], "-spuirq"))	            Config.SpuIrq = 1;
+		else if (!strcmp(argv[i], "-vsync"))	            Config.VSyncWA = 1;
+		else if (!strcmp(argv[i], "-fps")) 		            g_opts |=OPT_SHOWFPS;
+		else if (!strcmp(argv[i], "-cpu")) 		            g_opts |=OPT_SHOWCPU;
+		else if (!strcmp(argv[i], "-spu")) 		            g_opts |=OPT_SHOWSPU;
+		else if (!strcmp(argv[i], "-nofl")) 		        g_opts |=OPT_NO_FRAMELIM;
+		else if (!strcmp(argv[i], "-mcd1")) 	            sprintf(Config.Mcd1, "%s", argv[++i]);
+		else if (!strcmp(argv[i], "-mcd2")) 	            sprintf(Config.Mcd2, "%s", argv[++i]);
 
+		else if (!strcmp(argv[i], "-spu_reverb"))           { if (atol(argv[++i]) > 0) iUseReverb = 2; }
+		else if (!strcmp(argv[i], "-spu_interpolation")) 	iUseInterpolation = atol(argv[++i]);
 /*
 		else if (!strcmp(argv[i], "-neon_interlace")) 	pl_rearmed_cbs.gpu_neon.allow_interlace = atol(argv[++i]);
 */
@@ -207,7 +222,7 @@ int maemo_main(int argc, char **argv)
 	}
 
 	hildon_init(&argc, &argv);
-	
+
 	if (cdfile) {
 		set_cd_image(cdfile);
 		strcpy(file_name, strrchr(cdfile,'/'));
