@@ -16,13 +16,13 @@
  *                                                                         *
  ***************************************************************************/
 
-//*************************************************************************// 
+//*************************************************************************//
 // History of changes:
 //
-// 2009/03/08 - Pete  
+// 2009/03/08 - Pete
 // - generic cleanup for the Peops release
 //
-//*************************************************************************// 
+//*************************************************************************//
 
 //#include "gpuStdafx.h"
 
@@ -148,9 +148,9 @@ void ResizeWindow()
  rRatioRect.bottom = iResY;
  glViewport(rRatioRect.left,                           // init viewport by ratio rect
             iResY-(rRatioRect.top+rRatioRect.bottom),
-            rRatioRect.right, 
+            rRatioRect.right,
             rRatioRect.bottom); glError();
-                                                      
+
  glScissor(0, 0, iResX, iResY); glError();             // init clipping (fullscreen)
  glEnable(GL_SCISSOR_TEST); glError();
 
@@ -158,7 +158,7 @@ void ResizeWindow()
  glMatrixMode(GL_TEXTURE);                             // init psx tex sow and tow if not "ownscale"
  glLoadIdentity();
  glScalef(1.0f/255.99f,1.0f/255.99f,1.0f);             // geforce precision hack
-#endif 
+#endif
 
  glMatrixMode(GL_PROJECTION); glError();               // init projection with psx resolution
  glLoadIdentity(); glError();
@@ -218,12 +218,12 @@ char * GetConfigInfos(int hW)
    strcat(pB,szTxt);
    if(bChangeRes) sprintf(szTxt,"- Desktop changing [%d Bit]\r\n",iColDepth);
    else           sprintf(szTxt,"- NO desktop changing\r\n");
-  }                                                                                   
+  }
  strcat(pB,szTxt);
 
 // if(iForceVSync>=0) sprintf(szTxt,"- V-Sync: %s\r\n",szO[iForceVSync]);
 // else               strcpy(szTxt,"- V-Sync: Driver\r\n");
- strcat(pB,szTxt); 
+ strcat(pB,szTxt);
  sprintf(szTxt,"- Keep psx aspect ratio: %s\r\n\r\n",szO[bKeepRatio]);
  strcat(pB,szTxt);
  //----------------------------------------------------//
@@ -245,11 +245,11 @@ char * GetConfigInfos(int hW)
  else sprintf(szTxt,"- iFiltering: %d\r\n",iFilterType);
  strcat(pB,szTxt);
  sprintf(szTxt,"- Hi-Res textures: %d\r\n",iHiResTextures);
- strcat(pB,szTxt); 
+ strcat(pB,szTxt);
  if(!hW)
   {
    sprintf(szTxt,"- Palettized tex windows: %s\r\n",szO[iUsePalTextures]);
-   strcat(pB,szTxt); 
+   strcat(pB,szTxt);
   }
  !*/
  /*sprintf(szTxt,"- VRam size: %d MBytes",iVRamSize);
@@ -304,8 +304,8 @@ char * GetConfigInfos(int hW)
    strcat(szTxt,"\r\n\r\n");
   }
  else strcpy(szTxt,"\r\n");
- 
- strcat(pB,szTxt);             
+
+ strcat(pB,szTxt);
  //----------------------------------------------------//
  sprintf(szTxt,"Misc:\r\n- Scanlines: %s",szO[iUseScanLines]);
  strcat(pB,szTxt);
@@ -324,7 +324,7 @@ char * GetConfigInfos(int hW)
  strcat(pB,szTxt);
  sprintf(szTxt,"- Screen smoothing: %s",szO[iBlurBuffer]);
  strcat(pB,szTxt);
- if(!hW && iBlurBuffer) 
+ if(!hW && iBlurBuffer)
   {
    if(gTexBlurName) strcat(pB," - supported\r\n");
    else             strcat(pB," - not supported\r\n");
@@ -350,12 +350,12 @@ void DoTextSnapShot(int iNum)
 
 void DoSnapShot(void)
 {
-}       
+}
 
 void CALLBACK GPUmakeSnapshot(void)
 {
  //bSnapShot = TRUE;
-}        
+}
 
 ////////////////////////////////////////////////////////////////////////
 // GPU INIT... here starts it all (first func called by emu)
@@ -367,7 +367,6 @@ memset(ulStatusControl,0,256*sizeof(unsigned long));
 
 bChangeRes=FALSE;
 bWindowMode=FALSE;
-
 bKeepRatio = TRUE;
 // different ways of accessing PSX VRAM
 
@@ -436,17 +435,17 @@ GPUIsIdle;
 GPUIsReadyForCommands;
 
 return 0;
-}                             
+}
 
 
 ////////////////////////////////////////////////////////////////////////
-// OPEN interface func: attention! 
+// OPEN interface func: attention!
 // some emus are calling this func in their main Window thread,
 // but all other interface funcs (to draw stuff) in a different thread!
-// that's a problem, since OGL is thread safe! Therefore we cannot 
+// that's a problem, since OGL is thread safe! Therefore we cannot
 // initialize the OGL stuff right here, we simply set a "bIsFirstFrame = TRUE"
 // flag, to initialize OGL on the first real draw call.
-// btw, we also call this open func ourselfes, each time when the user 
+// btw, we also call this open func ourselfes, each time when the user
 // is changing between fullscreen/window mode (ENTER key)
 // btw part 2: in windows the plugin gets the window handle from the
 // main emu, and doesn't create it's own window (if it would do it,
@@ -460,9 +459,9 @@ long CALLBACK GPUopen(int hwndGPU)
 	 bChangeRes=FALSE;
 	 bWindowMode=FALSE;
 	 bFullVRam=FALSE;
-	 iFilterType=0;
+	 //iFilterType=0;
 	// bAdvancedBlend=FALSE;
-	 bDrawDither=FALSE;
+	 //bDrawDither=FALSE;
 	// bUseLines=FALSE;
 	 bUseFrameLimit=FALSE;
 	 bUseFrameSkip=FALSE;
@@ -472,21 +471,21 @@ long CALLBACK GPUopen(int hwndGPU)
 	 //bOpaquePass=FALSE;
 	 //bUseAntiAlias=FALSE;
 	 //iTexQuality=0;
-	 iUseMask=0;
+	 //iUseMask=0;
 	 iZBufferDepth=0;
-	 bUseFastMdec=FALSE;
+	 //bUseFastMdec=FALSE;
 	 bUse15bitMdec=FALSE;
 	 dwCfgFixes=0;
 	 bUseFixes=FALSE;
 	// iUseScanLines=0;
-	 iFrameTexType=0;
+	 //iFrameTexType=0;
 	 iFrameReadType=0;
 	 //iShowFPS=0;
-	 bKeepRatio=TRUE;
+     //bKeepRatio = TRUE;
 	 iScanBlend=0;
-	 iVRamSize=0;
+	 //iVRamSize=0;
 	 iTexGarbageCollection=0;
-	 iBlurBuffer=0; 
+	 iBlurBuffer=0;
 	 //iHiResTextures=0;
 	 iNoScreenSaver=0;
  //iForceVSync=0;
@@ -499,7 +498,7 @@ long CALLBACK GPUopen(int hwndGPU)
  rRatioRect.right  = iResX;
  rRatioRect.bottom = iResY;
 
- bDisplayNotSet = TRUE; 
+ bDisplayNotSet = TRUE;
  bSetClip=TRUE;
 
  SetFixes();                                           // setup game fixes
@@ -513,7 +512,7 @@ long CALLBACK GPUopen(int hwndGPU)
  // with some emus, we could do the OGL init right here... oh my
  if(bIsFirstFrame) GLinitialize();
 
-  extern Display*                x11Display ;	
+  extern Display*                x11Display ;
   return x11Display;
 }
 
@@ -535,7 +534,7 @@ long GPUclose()                                        // LINUX CLOSE
 }
 
 ////////////////////////////////////////////////////////////////////////
-// I shot the sheriff... last function called from emu 
+// I shot the sheriff... last function called from emu
 ////////////////////////////////////////////////////////////////////////
 
 long CALLBACK GPUshutdown()
@@ -568,8 +567,8 @@ void PaintBlackBorders(void)
 // helper to draw scanlines
 ////////////////////////////////////////////////////////////////////////
 
-__inline void XPRIMdrawTexturedQuad(OGLVertex* vertex1, OGLVertex* vertex2, 
-                                    OGLVertex* vertex3, OGLVertex* vertex4) 
+__inline void XPRIMdrawTexturedQuad(OGLVertex* vertex1, OGLVertex* vertex2,
+                                    OGLVertex* vertex3, OGLVertex* vertex4)
 {
 
 }
@@ -588,7 +587,7 @@ void SetScanLines(void)
 
 
 ////////////////////////////////////////////////////////////////////////
-// Update display (swap buffers)... called in interlaced mode on 
+// Update display (swap buffers)... called in interlaced mode on
 // every emulated vsync, otherwise whenever the displayed screen region
 // has been changed
 ////////////////////////////////////////////////////////////////////////
@@ -635,7 +634,7 @@ if(bNeedInterlaceUpdate)                              // smaller upload?
   UploadScreen(TRUE);
  }
 
-if(dwActFixes&512) bCheckFF9G4(NULL);                 // special game fix for FF9 
+if(dwActFixes&512) bCheckFF9G4(NULL);                 // special game fix for FF9
 
 if(PreviousPSXDisplay.Range.x0||                      // paint black borders around display area, if needed
    PreviousPSXDisplay.Range.y0)
@@ -646,10 +645,10 @@ if(PSXDisplay.Disabled)                               // display disabled?
   //LOGE("PSXDisplay.Disabled");
 
   // moved here
-  glDisable(GL_SCISSOR_TEST); glError();                       
+  glDisable(GL_SCISSOR_TEST); glError();
   glClearColor(0,0,0,128); glError();                 // -> clear whole backbuffer
   glClear(uiBufferBits); glError();
-  glEnable(GL_SCISSOR_TEST); glError();                       
+  glEnable(GL_SCISSOR_TEST); glError();
   gl_z=0.0f;
   bDisplayNotSet = TRUE;
  }
@@ -670,8 +669,8 @@ if(iSkipTwo)                                          // we are in skipping mood
 if(dwActFixes&128)                                    // special FPS limitation mode?
  {
   if(bUseFrameLimit) PCFrameCap();                    // -> ok, do it
-//   if(bUseFrameSkip || ulKeybits&KEY_SHOWFPS)  
-   PCcalcfps();         
+//   if(bUseFrameSkip || ulKeybits&KEY_SHOWFPS)
+   PCcalcfps();
  }
 
 // if(gTexPicName) DisplayPic();                         // some gpu info picture active? display it
@@ -689,11 +688,11 @@ if(dwActFixes&128)                                    // special FPS limitation
 
 if(bUseFrameSkip)                                     // frame skipping active ?
  {
-  if(!bSkipNextFrame) 
+  if(!bSkipNextFrame)
    {
     if(iDrawnSomething)     flipEGL();
    }
-    if((fps_skip < fFrameRateHz) && !(bSkipNextFrame)) 
+    if((fps_skip < fFrameRateHz) && !(bSkipNextFrame))
      {bSkipNextFrame = TRUE; fps_skip=fFrameRateHz;}
     else bSkipNextFrame = FALSE;
 
@@ -717,13 +716,13 @@ if(lClearOnSwap)                                      // clear buffer after swap
   g=((GLclampf)GREEN(lClearOnSwapColor))/255.0f;      // -> get col
   b=((GLclampf)BLUE(lClearOnSwapColor))/255.0f;
   r=((GLclampf)RED(lClearOnSwapColor))/255.0f;
-  glDisable(GL_SCISSOR_TEST); glError();                       
-  glClearColor(r,g,b,128); glError();                 // -> clear 
+  glDisable(GL_SCISSOR_TEST); glError();
+  glClearColor(r,g,b,128); glError();                 // -> clear
   glClear(uiBufferBits); glError();
-  glEnable(GL_SCISSOR_TEST); glError();                       
+  glEnable(GL_SCISSOR_TEST); glError();
   lClearOnSwap=0;                                     // -> done
  }
-else 
+else
  {
 //  if(bBlur) UnBlurBackBuffer();                       // unblur buff, if blurred before
 
@@ -742,7 +741,7 @@ gl_z=0.0f;
 
 if(bNeedUploadAfter)                                  // upload wanted?
  {
-  bNeedUploadAfter=FALSE;                           
+  bNeedUploadAfter=FALSE;
   bNeedUploadTest=FALSE;
   UploadScreen(-1);                                   // -> upload
  }
@@ -770,17 +769,17 @@ if(iRumbleTime)                                       // shake screen by modifyi
   int i1=0,i2=0,i3=0,i4=0;
 
   iRumbleTime--;
-  if(iRumbleTime) 
+  if(iRumbleTime)
    {
-    i1=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2); 
-    i2=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2); 
-    i3=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2); 
-    i4=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2); 
+    i1=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2);
+    i2=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2);
+    i3=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2);
+    i4=((rand()*iRumbleVal)/RAND_MAX)-(iRumbleVal/2);
    }
 
-  glViewport(rRatioRect.left+i1,                      
+  glViewport(rRatioRect.left+i1,
              iResY-(rRatioRect.top+rRatioRect.bottom)+i2,
-             rRatioRect.right+i3, 
+             rRatioRect.right+i3,
              rRatioRect.bottom+i4); glError();
  }
 
@@ -792,7 +791,7 @@ if(iRumbleTime)                                       // shake screen by modifyi
 }
 
 ////////////////////////////////////////////////////////////////////////
-// update front display: smaller update func, if something has changed 
+// update front display: smaller update func, if something has changed
 // in the frontbuffer... dirty, but hey... real men know no pain
 ////////////////////////////////////////////////////////////////////////
 
@@ -820,7 +819,7 @@ if(iDrawnSomething)                                   // linux:
 
 //if(iBlurBuffer) UnBlurBackBuffer();
 }
-                                             
+
 ////////////////////////////////////////////////////////////////////////
 // check if update needed
 ////////////////////////////////////////////////////////////////////////
@@ -859,7 +858,7 @@ else                                                  // range smaller? center i
     PreviousPSXDisplay.Range.x0=                      // -> adjust start
      PSXDisplay.DisplayMode.x-lx;
     PreviousPSXDisplay.Range.x1+=lx-l;                // -> adjust width
-   }                   
+   }
  }
 
 if(sO!=PreviousPSXDisplay.Range.x0)                   // something changed?
@@ -880,7 +879,7 @@ if(PSXDisplay.Range.y0>=iT)                           // crossed the security li
  {
   PreviousPSXDisplay.Range.y1=                        // -> store width
    PSXDisplay.DisplayModeNew.y;
-  
+
   sO=(PSXDisplay.Range.y0-iT-4)*PSXDisplay.Double;    // -> calc offset
   if(sO<0) sO=0;
 
@@ -936,7 +935,7 @@ if(r.bottom<rRatioRect.bottom ||
     glClear(uiBufferBits); glError();
     rC.left=iResX-rC.right;
     glScissor(rC.left,rC.top,rC.right,rC.bottom); glError();
-    
+
     glClear(uiBufferBits); glError();
    }
 
@@ -953,7 +952,7 @@ if(r.bottom<rRatioRect.bottom ||
     glScissor(rC.left,rC.top,rC.right,rC.bottom); glError();
     glClear(uiBufferBits); glError();
    }
-  
+
   bSetClip=TRUE;
   bDisplayNotSet=TRUE;
  }
@@ -964,7 +963,11 @@ rRatioRect=r;
  if (rearmed_get_layer_pos != NULL)
    rearmed_get_layer_pos(&rRatioRect.left, &rRatioRect.top, &rRatioRect.right, &rRatioRect.bottom);
 #endif
-
+/*printf("glViewport: %i, %i, %i, %i\n",
+       rRatioRect.left,
+       iResY-(rRatioRect.top+rRatioRect.bottom),
+       rRatioRect.right,
+       rRatioRect.bottom);*/
 glViewport(rRatioRect.left,
            iResY-(rRatioRect.top+rRatioRect.bottom),
            rRatioRect.right,
@@ -979,11 +982,11 @@ void updateDisplayIfChanged(void)
 {
 BOOL bUp;
 
-if ((PSXDisplay.DisplayMode.y == PSXDisplay.DisplayModeNew.y) && 
+if ((PSXDisplay.DisplayMode.y == PSXDisplay.DisplayModeNew.y) &&
     (PSXDisplay.DisplayMode.x == PSXDisplay.DisplayModeNew.x))
  {
-  if((PSXDisplay.RGB24      == PSXDisplay.RGB24New) && 
-     (PSXDisplay.Interlaced == PSXDisplay.InterlacedNew)) 
+  if((PSXDisplay.RGB24      == PSXDisplay.RGB24New) &&
+     (PSXDisplay.Interlaced == PSXDisplay.InterlacedNew))
      return;                                          // nothing has changed? fine, no swap buffer needed
  }
 else                                                  // some res change?
@@ -1008,7 +1011,7 @@ PSXDisplay.RGB24         = PSXDisplay.RGB24New;       // get new infos
 PSXDisplay.DisplayMode.y = PSXDisplay.DisplayModeNew.y;
 PSXDisplay.DisplayMode.x = PSXDisplay.DisplayModeNew.x;
 PSXDisplay.Interlaced    = PSXDisplay.InterlacedNew;
-   
+
 PSXDisplay.DisplayEnd.x=                              // calc new ends
  PSXDisplay.DisplayPosition.x+ PSXDisplay.DisplayMode.x;
 PSXDisplay.DisplayEnd.y=
@@ -1059,13 +1062,13 @@ if(PSXDisplay.Interlaced) return FALSE;
 
 if (bNeedInterlaceUpdate||
     bNeedRGB24Update ||
-    bNeedUploadAfter|| 
-    bNeedUploadTest || 
+    bNeedUploadAfter||
+    bNeedUploadTest ||
     iDoAgain
    )
  {
   iDoAgain=0;
-  if(bNeedUploadAfter) 
+  if(bNeedUploadAfter)
    iDoAgain=1;
   if(bNeedUploadTest && PSXDisplay.InterlacedTest)
    iDoAgain=1;
@@ -1084,13 +1087,13 @@ if (bNeedInterlaceUpdate||
  }
 
 return FALSE;
-} 
+}
 ////////////////////////////////////////////////////////////////////////
 // gun cursor func: player=0-7, x=0-511, y=0-255
 ////////////////////////////////////////////////////////////////////////
 
 ////////////////////////////////////////////////////////////////////////
-// update lace is called every VSync. Basically we limit frame rate 
+// update lace is called every VSync. Basically we limit frame rate
 // here, and in interlaced mode we swap ogl display buffers.
 ////////////////////////////////////////////////////////////////////////
 
@@ -1098,7 +1101,7 @@ static unsigned short usFirstPos=2;
 
 void CALLBACK GPUupdateLace(void)
 {
-if(!(dwActFixes&0x1000))                               
+if(!(dwActFixes&0x1000))
  STATUSREG^=0x80000000;                               // interlaced bit toggle, if the CC game fix is not active (see gpuReadStatus)
 
 if(!(dwActFixes&128))                                 // normal frame limit func
@@ -1196,23 +1199,23 @@ switch(lCommand)
    return;
 
   // dis/enable display
-  case 0x03:  
+  case 0x03:
    PreviousPSXDisplay.Disabled = PSXDisplay.Disabled;
    PSXDisplay.Disabled = (gdata & 1);
 
-   if(PSXDisplay.Disabled) 
+   if(PSXDisplay.Disabled)
         STATUSREG|=GPUSTATUS_DISPLAYDISABLED;
    else STATUSREG&=~GPUSTATUS_DISPLAYDISABLED;
 
    if (iOffscreenDrawing==4 &&
-        PreviousPSXDisplay.Disabled && 
+        PreviousPSXDisplay.Disabled &&
        !(PSXDisplay.Disabled))
     {
 
      if(!PSXDisplay.RGB24)
       {
        PrepareFullScreenUpload(TRUE);
-       UploadScreen(TRUE); 
+       UploadScreen(TRUE);
        updateDisplay();
       }
     }
@@ -1233,20 +1236,20 @@ switch(lCommand)
    return;
 
   // setting display position
-  case 0x05: 
+  case 0x05:
    {
     short sx=(short)(gdata & 0x3ff);
     short sy;
 
     if(iGPUHeight==1024)
      {
-      if(dwGPUVersion==2) 
+      if(dwGPUVersion==2)
            sy = (short)((gdata>>12)&0x3ff);
       else sy = (short)((gdata>>10)&0x3ff);
      }
     else sy = (short)((gdata>>10)&0x3ff);             // really: 0x1ff, but we adjust it later
 
-    if (sy & 0x200) 
+    if (sy & 0x200)
      {
       sy|=0xfc00;
       PreviousPSXDisplay.DisplayModeNew.y=sy/PSXDisplay.Double;
@@ -1268,7 +1271,7 @@ switch(lCommand)
        }
      }
 
-    if(dwActFixes&8) 
+    if(dwActFixes&8)
      {
       if((!PSXDisplay.Interlaced) &&
          PreviousPSXDisplay.DisplayPosition.x == sx  &&
@@ -1309,7 +1312,7 @@ switch(lCommand)
       updateDisplay();
      }
     else
-    if(PSXDisplay.InterlacedTest && 
+    if(PSXDisplay.InterlacedTest &&
        ((PreviousPSXDisplay.DisplayPosition.x != PSXDisplay.DisplayPosition.x)||
         (PreviousPSXDisplay.DisplayPosition.y != PSXDisplay.DisplayPosition.y)))
      PSXDisplay.InterlacedTest--;
@@ -1337,7 +1340,7 @@ switch(lCommand)
    PSXDisplay.Range.y0=gdata & 0x3ff;
    PSXDisplay.Range.y1=(gdata>>10) & 0x3ff;
 
-   PSXDisplay.Height = PSXDisplay.Range.y1 - 
+   PSXDisplay.Height = PSXDisplay.Range.y1 -
                        PSXDisplay.Range.y0 +
                        PreviousPSXDisplay.DisplayModeNew.y;
 
@@ -1359,7 +1362,7 @@ switch(lCommand)
    PSXDisplay.DisplayModeNew.y = PSXDisplay.Height*PSXDisplay.Double;
 
    ChangeDispOffsetsY();
- 
+
    PSXDisplay.PAL           = (gdata & 0x08)?TRUE:FALSE; // if 1 - PAL mode, else NTSC
    PSXDisplay.RGB24New      = (gdata & 0x10)?TRUE:FALSE; // if 1 - TrueColor
    PSXDisplay.InterlacedNew = (gdata & 0x20)?TRUE:FALSE; // if 1 - Interlace
@@ -1367,7 +1370,7 @@ switch(lCommand)
    STATUSREG&=~GPUSTATUS_WIDTHBITS;                   // clear the width bits
 
    STATUSREG|=
-              (((gdata & 0x03) << 17) | 
+              (((gdata & 0x03) << 17) |
               ((gdata & 0x40) << 10));                // set the width bits
 
    PreviousPSXDisplay.InterlacedNew=FALSE;
@@ -1383,7 +1386,7 @@ switch(lCommand)
 
      STATUSREG|=GPUSTATUS_INTERLACED;
     }
-   else 
+   else
     {
      PSXDisplay.InterlacedTest=0;
      STATUSREG&=~GPUSTATUS_INTERLACED;
@@ -1407,11 +1410,11 @@ switch(lCommand)
 
   //--------------------------------------------------//
   // ask about GPU version and other stuff
-  case 0x10: 
+  case 0x10:
 
    gdata&=0xff;
 
-   switch(gdata) 
+   switch(gdata)
     {
      case 0x02:
       GPUdataRet=ulGPUInfoVals[INFO_TW];              // tw infos
@@ -1508,7 +1511,7 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
      (dy  > PreviousPSXDisplay.DisplayPosition.y) &&
      (y   < PreviousPSXDisplay.DisplayEnd.y)))
   sArea=1;
- else 
+ else
   {
    return;
   }
@@ -1535,7 +1538,7 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
        PreviousPSXDisplay.DisplayPosition.x)==udx &&
       (PreviousPSXDisplay.DisplayEnd.y-
        PreviousPSXDisplay.DisplayPosition.y)==udy)
-    p2=(psxVuw + (1024*PreviousPSXDisplay.DisplayPosition.y) + 
+    p2=(psxVuw + (1024*PreviousPSXDisplay.DisplayPosition.y) +
         PreviousPSXDisplay.DisplayPosition.x);
   }
  else
@@ -1548,7 +1551,7 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
        PSXDisplay.DisplayPosition.x)==udx &&
       (PSXDisplay.DisplayEnd.y-
        PSXDisplay.DisplayPosition.y)==udy)
-    p2=(psxVuw + (1024*PSXDisplay.DisplayPosition.y) + 
+    p2=(psxVuw + (1024*PSXDisplay.DisplayPosition.y) +
         PSXDisplay.DisplayPosition.x);
   }
 
@@ -1592,7 +1595,7 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
   }
 
  ps=pGfxCardScreen;
- 
+
  //if(!sArea) glReadBuffer(GL_FRONT);
 
  glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps); glError();
@@ -1602,7 +1605,7 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
 
  XS=(float)dx/(float)(udx);
  YS=(float)dy/(float)(udy+1);
-    
+
  for(y=udy;y>0;y--)
   {
    for(x=0;x<udx;x++)
@@ -1632,7 +1635,7 @@ void CheckVRamReadEx(int x, int y, int dx, int dy)
 }
 
 ////////////////////////////////////////////////////////////////////////
-// vram read check (reading from card's back/frontbuffer if needed... 
+// vram read check (reading from card's back/frontbuffer if needed...
 // slow!)
 ////////////////////////////////////////////////////////////////////////
 
@@ -1657,7 +1660,7 @@ void CheckVRamRead(int x, int y, int dx, int dy, bool bFront)
      (dy  > PreviousPSXDisplay.DisplayPosition.y) &&
      (y   < PreviousPSXDisplay.DisplayEnd.y)))
   sArea=1;
- else 
+ else
   {
    return;
   }
@@ -1697,7 +1700,7 @@ void CheckVRamRead(int x, int y, int dx, int dy, bool bFront)
  if(dy>wy) {udy-=(dy-wy);dy=wy;}
  udx-=ux;
  udy-=uy;
-  
+
  p=(psxVuw + (1024*uy) + ux);
 
  if(udx<=0) return;
@@ -1739,7 +1742,7 @@ void CheckVRamRead(int x, int y, int dx, int dy, bool bFront)
   }
 
  ps=pGfxCardScreen;
- 
+
 // if(bFront) glReadBuffer(GL_FRONT);
 
  glReadPixels(x,y,dx,dy,GL_RGB,GL_UNSIGNED_BYTE,ps); glError(); glError();
@@ -1747,7 +1750,7 @@ void CheckVRamRead(int x, int y, int dx, int dy, bool bFront)
 
  XS=(float)dx/(float)(udx);
  YS=(float)dy/(float)(udy+1);
-    
+
  for(y=udy;y>0;y--)
   {
    for(x=0;x<udx;x++)
@@ -2040,13 +2043,13 @@ if(iDataWriteMode==DR_NORMAL)
       if(dwEmuFixes&0x0001 || dwActFixes&0x20000)     // hack for emulating "gpu busy" in some games
        iFakePrimBusy=4;
      }
-   } 
+   }
  }
 
 GPUdataRet=gdata;
 
 GPUIsReadyForCommands;
-GPUIsIdle;                
+GPUIsIdle;
 }
 
 ////////////////////////////////////////////////////////////////////////
@@ -2152,7 +2155,7 @@ void SetFixes(void)
 {
  ReInitFrameCap();
 
- if(dwActFixes & 0x2000) 
+ if(dwActFixes & 0x2000)
       dispWidths[4]=384;
  else dispWidths[4]=368;
 }
@@ -2204,7 +2207,7 @@ do
   dmaMem=addr+4;
 
   if(count>0) GPUwriteDataMem(&baseAddrL[dmaMem>>2],count);
-  
+
   addr = baseAddrL[addr>>2]&0xffffff;
  }
 while (addr != 0xffffff);
@@ -2213,7 +2216,7 @@ GPUIsIdle;
 
 return 0;
 }
-           
+
 ////////////////////////////////////////////////////////////////////////
 // show about dlg
 ////////////////////////////////////////////////////////////////////////
@@ -2243,7 +2246,7 @@ long CALLBACK GPUtest(void)
 
 long CALLBACK GPUfreeze(unsigned long ulGetFreezeData,GPUFreeze_t * pF)
 {
-if(ulGetFreezeData==2) 
+if(ulGetFreezeData==2)
  {
   long lSlotNum=*((long *)pF);
   if(lSlotNum<0) return 0;
@@ -2252,7 +2255,7 @@ if(ulGetFreezeData==2)
   return 1;
  }
 
-if(!pF)                    return 0; 
+if(!pF)                    return 0;
 if(pF->ulFreezeVersion!=1) return 0;
 
 if(ulGetFreezeData==1)
@@ -2545,7 +2548,7 @@ long CALLBACK GPUgetScreenPic(unsigned char * pMem)
 // glReadBuffer(GL_FRONT);
 
  glReadPixels(0,0,iResX,iResY,GL_RGB,GL_UNSIGNED_BYTE,ps); glError();
-               
+
 // glReadBuffer(GL_BACK);
 
  XS=(float)iResX/128;
@@ -2622,7 +2625,7 @@ void CALLBACK GPUsetfix(unsigned long dwFixBits)
 }
 
 ////////////////////////////////////////////////////////////////////////
- 
+
 void CALLBACK GPUvisualVibration(unsigned long iSmall, unsigned long iBig)
 {
  int iVibVal;
@@ -2638,9 +2641,9 @@ void CALLBACK GPUvisualVibration(unsigned long iSmall, unsigned long iBig)
 
  iRumbleTime=15;                                       // let the rumble last 16 buffer swaps
 }
-                                                       
+
 ////////////////////////////////////////////////////////////////////////
-// main emu can set display infos (A/M/G/D) 
+// main emu can set display infos (A/M/G/D)
 ////////////////////////////////////////////////////////////////////////
 
 void CALLBACK GPUdisplayFlags(unsigned long dwFlags)
@@ -2649,12 +2652,26 @@ void CALLBACK GPUdisplayFlags(unsigned long dwFlags)
 }
 
 // pcsx-rearmed callbacks
+#include "../../frontend/plugin_lib.h"
 void CALLBACK GPUrearmedCallbacks(const void **cbs)
 {
- rearmed_get_layer_pos = cbs[0];
+    rearmed_get_layer_pos = cbs[0];
+
+    const struct rearmed_cbs *cbs_ = (const struct rearmed_cbs *)cbs;
+    bKeepRatio = cbs_->gpu_peopsgl.bKeepRatio;
+    dwActFixes = cbs_->gpu_peopsgl.dwActFixes;
+    bDrawDither = cbs_->gpu_peopsgl.bDrawDither;
+    iFilterType = cbs_->gpu_peopsgl.iFilterType;
+    iFrameTexType = cbs_->gpu_peopsgl.iFrameTexType;
+    iUseMask = cbs_->gpu_peopsgl.iUseMask;
+    bOpaquePass = cbs_->gpu_peopsgl.bOpaquePass;
+    bAdvancedBlend = cbs_->gpu_peopsgl.bAdvancedBlend;
+    bUseFastMdec = cbs_->gpu_peopsgl.bUseFastMdec;
+    iTexGarbageCollection = cbs_->gpu_peopsgl.iTexGarbageCollection;
+    iVRamSize = cbs_->gpu_peopsgl.iVRamSize;
 }
 
 static void flipEGL(void)
 {
- eglSwapBuffers(display, surface);
+    eglSwapBuffers(display, surface);
 }
