@@ -109,15 +109,15 @@ void updateDisplay(void)
   UploadScreen(TRUE);
  }
 
- if(dwActFixes&512) bCheckFF9G4(NULL);                // special game fix for FF9 
+ if(dwActFixes&512) bCheckFF9G4(NULL);                // special game fix for FF9
 
  if(PSXDisplay.Disabled)                              // display disabled?
  {
   // moved here
-  glDisable(GL_SCISSOR_TEST); glError();                       
+  glDisable(GL_SCISSOR_TEST); glError();
   glClearColor(0,0,0,128); glError();                 // -> clear whole backbuffer
   glClear(uiBufferBits); glError();
-  glEnable(GL_SCISSOR_TEST); glError();                       
+  glEnable(GL_SCISSOR_TEST); glError();
   gl_z=0.0f;
   bDisplayNotSet = TRUE;
  }
@@ -139,13 +139,13 @@ void updateDisplay(void)
   g=((GLclampf)GREEN(lClearOnSwapColor))/255.0f;      // -> get col
   b=((GLclampf)BLUE(lClearOnSwapColor))/255.0f;
   r=((GLclampf)RED(lClearOnSwapColor))/255.0f;
-  glDisable(GL_SCISSOR_TEST); glError();                       
-  glClearColor(r,g,b,128); glError();                 // -> clear 
+  glDisable(GL_SCISSOR_TEST); glError();
+  glClearColor(r,g,b,128); glError();                 // -> clear
   glClear(uiBufferBits); glError();
-  glEnable(GL_SCISSOR_TEST); glError();                       
+  glEnable(GL_SCISSOR_TEST); glError();
   lClearOnSwap=0;                                     // -> done
  }
- else 
+ else
  {
   if(iZBufferDepth)                                   // clear zbuffer as well (if activated)
    {
@@ -159,7 +159,7 @@ void updateDisplay(void)
  // additional uploads immediatly after swapping
  if(bNeedUploadAfter)                                 // upload wanted?
  {
-  bNeedUploadAfter=FALSE;                           
+  bNeedUploadAfter=FALSE;
   bNeedUploadTest=FALSE;
   UploadScreen(-1);                                   // -> upload
  }
@@ -228,7 +228,7 @@ else                                                  // range smaller? center i
     PreviousPSXDisplay.Range.x0=                      // -> adjust start
      PSXDisplay.DisplayMode.x-lx;
     PreviousPSXDisplay.Range.x1+=lx-l;                // -> adjust width
-   }                   
+   }
  }
 
 if(sO!=PreviousPSXDisplay.Range.x0)                   // something changed?
@@ -249,7 +249,7 @@ if(PSXDisplay.Range.y0>=iT)                           // crossed the security li
  {
   PreviousPSXDisplay.Range.y1=                        // -> store width
    PSXDisplay.DisplayModeNew.y;
-  
+
   sO=(PSXDisplay.Range.y0-iT-4)*PSXDisplay.Double;    // -> calc offset
   if(sO<0) sO=0;
 
@@ -268,11 +268,11 @@ static void updateDisplayIfChanged(void)
 {
 BOOL bUp;
 
-if ((PSXDisplay.DisplayMode.y == PSXDisplay.DisplayModeNew.y) && 
+if ((PSXDisplay.DisplayMode.y == PSXDisplay.DisplayModeNew.y) &&
     (PSXDisplay.DisplayMode.x == PSXDisplay.DisplayModeNew.x))
  {
-  if((PSXDisplay.RGB24      == PSXDisplay.RGB24New) && 
-     (PSXDisplay.Interlaced == PSXDisplay.InterlacedNew)) 
+  if((PSXDisplay.RGB24      == PSXDisplay.RGB24New) &&
+     (PSXDisplay.Interlaced == PSXDisplay.InterlacedNew))
      return;                                          // nothing has changed? fine, no swap buffer needed
  }
 else                                                  // some res change?
@@ -329,31 +329,31 @@ switch((gdata>>24)&0xff)
    bUsingTWin = FALSE;
    return;
 
-  case 0x03:  
+  case 0x03:
    PreviousPSXDisplay.Disabled = PSXDisplay.Disabled;
    PSXDisplay.Disabled = (gdata & 1);
 
    if (iOffscreenDrawing==4 &&
-        PreviousPSXDisplay.Disabled && 
+        PreviousPSXDisplay.Disabled &&
        !(PSXDisplay.Disabled))
     {
 
      if(!PSXDisplay.RGB24)
       {
        PrepareFullScreenUpload(TRUE);
-       UploadScreen(TRUE); 
+       UploadScreen(TRUE);
        updateDisplay();
       }
     }
    return;
 
-  case 0x05: 
+  case 0x05:
    {
     short sx=(short)(gdata & 0x3ff);
     short sy;
 
     sy = (short)((gdata>>10)&0x3ff);             // really: 0x1ff, but we adjust it later
-    if (sy & 0x200) 
+    if (sy & 0x200)
      {
       sy|=0xfc00;
       PreviousPSXDisplay.DisplayModeNew.y=sy/PSXDisplay.Double;
@@ -363,7 +363,7 @@ switch((gdata>>24)&0xff)
 
     if(sx>1000) sx=0;
 
-    if(dwActFixes&8) 
+    if(dwActFixes&8)
      {
       if((!PSXDisplay.Interlaced) &&
          PreviousPSXDisplay.DisplayPosition.x == sx  &&
@@ -404,7 +404,7 @@ switch((gdata>>24)&0xff)
       updateDisplay();
      }
     else
-    if(PSXDisplay.InterlacedTest && 
+    if(PSXDisplay.InterlacedTest &&
        ((PreviousPSXDisplay.DisplayPosition.x != PSXDisplay.DisplayPosition.x)||
         (PreviousPSXDisplay.DisplayPosition.y != PSXDisplay.DisplayPosition.y)))
      PSXDisplay.InterlacedTest--;
@@ -426,7 +426,7 @@ switch((gdata>>24)&0xff)
    PSXDisplay.Range.y0=gdata & 0x3ff;
    PSXDisplay.Range.y1=(gdata>>10) & 0x3ff;
 
-   PSXDisplay.Height = PSXDisplay.Range.y1 - 
+   PSXDisplay.Height = PSXDisplay.Range.y1 -
                        PSXDisplay.Range.y0 +
                        PreviousPSXDisplay.DisplayModeNew.y;
 
@@ -446,7 +446,7 @@ switch((gdata>>24)&0xff)
    PSXDisplay.DisplayModeNew.y = PSXDisplay.Height*PSXDisplay.Double;
 
    ChangeDispOffsetsY();
- 
+
    PSXDisplay.PAL           = (gdata & 0x08)?TRUE:FALSE; // if 1 - PAL mode, else NTSC
    PSXDisplay.RGB24New      = (gdata & 0x10)?TRUE:FALSE; // if 1 - TrueColor
    PSXDisplay.InterlacedNew = (gdata & 0x20)?TRUE:FALSE; // if 1 - Interlace
@@ -462,7 +462,7 @@ switch((gdata>>24)&0xff)
        PreviousPSXDisplay.InterlacedNew=TRUE;
       }
     }
-   else 
+   else
     {
      PSXDisplay.InterlacedTest=0;
     }
@@ -652,7 +652,7 @@ long GPUopen(void **dpy)
  rRatioRect.right  = iResX;
  rRatioRect.bottom = iResY;
 
- bDisplayNotSet = TRUE; 
+ bDisplayNotSet = TRUE;
  bSetClip = TRUE;
  CSTEXTURE = CSVERTEX = CSCOLOR = 0;
 
@@ -679,11 +679,11 @@ void renderer_set_config(const struct rearmed_cbs *cbs_)
 {
  cbs = (void *)cbs_; // ugh..
 
+ printf("renderer_set_config\n");
  iOffscreenDrawing = 0;
  iZBufferDepth = 0;
  iFrameReadType = 0;
- bKeepRatio = TRUE;
-
+ bKeepRatio = cbs->gpu_peopsgl.bKeepRatio;
  dwActFixes = cbs->gpu_peopsgl.dwActFixes;
  bDrawDither = cbs->gpu_peopsgl.bDrawDither;
  iFilterType = cbs->gpu_peopsgl.iFilterType;
